{
    'name': 'Hello',
    'category': 'Hidden',
    'description':"""
OpenERP Web example module.
===========================

""",
    'version': '2.0',
    'depends': [],
    'js': ['static/*/*.js', 'static/*/js/*.js'],
    'css': [],
    'auto_install': False,
    'web_preload': False,
}



#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `web_hello` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-web-hello",
    version = "7.0.406",
    description = "Hello",
    long_description = 
"""

OpenERP Web example module.
===========================

""",
    url = "",
    author = "",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.web_hello': ".",
    },
    packages = ["openerp.addons.web_hello"],
    package_data = {
        'openerp.addons.web_hello': ["i18n/*.po*","static/openerp/base_hello.js","i18n/cs.po","i18n/pt_BR.po","i18n/fr.po","i18n/ar.po","i18n/es_CR.po","static/*/*.js","static/*/js/*.js"],
    },
    install_requires = [],
    tests_require = ["unittest2"],
)
